// src/utils/bumpVersion.util.ts
import { readFileSync, writeFileSync } from "fs";
function updateVersion(pack) {
  const packageJson = JSON.parse(readFileSync(pack, "utf8"));
  const currentVersion = packageJson.version;
  const newVersion = increaseVersion(currentVersion);
  packageJson.version = newVersion;
  writeFileSync("package.json", JSON.stringify(packageJson, null, 2));
  console.log(`Version updated to ${newVersion}`);
}
function increaseVersion(version) {
  let partes = version.split(".");
  let ultimoElemento = partes.pop();
  if (!ultimoElemento)
    throw "problem with string version";
  let sufijo = "";
  if (ultimoElemento.includes("-")) {
    let sufijoPartes = ultimoElemento.split("-");
    ultimoElemento = sufijoPartes[0];
    sufijo = "-" + sufijoPartes.slice(1).join("-");
  }
  let ultimoNumero = parseInt(ultimoElemento);
  ultimoNumero++;
  partes.push(ultimoNumero.toString() + sufijo);
  let nuevaVersion = partes.join(".");
  return nuevaVersion;
}

// src/utils/date.util.ts
var getDay = () => {
  return getDate().getDay();
};
var getMonth = () => {
  return getDate().getMonth();
};
var getYear = () => {
  return getDate().getFullYear();
};
var getDate = () => {
  return /* @__PURE__ */ new Date();
};

// src/utils/folder.util.ts
import { readdirSync, statSync, mkdirSync, existsSync, copyFile } from "fs";
import path from "path";
function parsePath(path2) {
  return path2.replace(new RegExp("//", "g"), "/");
}
function findFolder(directory, nameFolder) {
  let pathFound = null;
  function searchInDirectory(directorio) {
    const elements = readdirSync(directorio);
    for (const element of elements) {
      const fullPath = path.join(directorio, element);
      const stats = statSync(fullPath);
      if (stats.isDirectory()) {
        if (element === nameFolder) {
          pathFound = fullPath;
          break;
        } else {
          searchInDirectory(fullPath);
        }
      }
    }
  }
  searchInDirectory(directory);
  return pathFound;
}
function createFolderIfNotExists(rutaCarpeta) {
  if (!existsSync(rutaCarpeta))
    mkdirSync(rutaCarpeta, { recursive: true });
}
function copyFolder(origin, destiny) {
  const sourceFolder = origin;
  const destinationFolder = destiny;
  copyFile(sourceFolder, destinationFolder, (err) => {
    if (err) {
      console.error("Error al copiar la carpeta:", err);
    } else {
      console.log("Carpeta copiada correctamente.");
    }
  });
}

// src/utils/formatter.util.ts
var formatToCLP = (valor) => {
  const onlyNumbers = valor.toString().replace(/[^0-9]/g, "");
  const number = Number(onlyNumbers);
  if (isNaN(number)) {
    return { result: "$0", number: 0 };
  }
  const formatCLP = new Intl.NumberFormat("es-CL", {
    style: "currency",
    currency: "CLP",
    minimumFractionDigits: 0,
    maximumFractionDigits: 0
  });
  return { number, result: formatCLP.format(number) };
};
function formatCapitalizeFirstLetter(texto) {
  return texto.charAt(0).toUpperCase() + texto.substring(1);
}
function withoutCharacterSpecial(chain) {
  const caracteresNoDeseados = /[^a-zA-Z0-9-_]/g;
  const cadenaLimpia = chain.replace(caracteresNoDeseados, "_");
  return cadenaLimpia;
}

// src/utils/formdata.util.ts
function FormData(formData, params) {
  const data = Object.entries(params);
  for (const [key, value] of data) {
    if (value)
      formData.append(key, value);
  }
  return formData;
}
function FormDataFile(formData, nameFile, FileList) {
  if (FileList) {
    for (var i = 0; i < FileList.length; i++) {
      var file = FileList[i];
      formData.append(nameFile, file, file.name);
    }
  }
  return formData;
}

// src/utils/images.util.ts
var downloadImage = async (url) => {
  if (!isImage(url))
    throw "No es Imagen";
  const response = await fetch(url);
  const blob = await response.blob();
  var enlace = document.createElement("a");
  var urlBlob = window.URL.createObjectURL(blob);
  enlace.href = urlBlob;
  var nombreArchivo = url.substring(url.lastIndexOf("/") + 1);
  enlace.download = nombreArchivo;
  enlace.click();
  window.URL.revokeObjectURL(urlBlob);
};
function isImage(url) {
  const extensionesImagen = /\.(jpg|jpeg|png|gif|bmp|svg)$/i;
  return extensionesImagen.test(url);
}

// src/utils/randomizer.util.ts
function randomAlphaNumeric(length) {
  const charset = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
  let result = "";
  for (let i = 0; i < length; i++) {
    const randomIndex = Math.floor(Math.random() * charset.length);
    result += charset[randomIndex];
  }
  return result;
}

// src/utils/simulate.util.ts
function simulatePromise(result) {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(result);
    }, 1e3);
  });
}
function simulatePromiseRandom(result) {
  return new Promise((resolve, reject) => {
    const randomNumber = Math.random();
    if (randomNumber < 0.5) {
      resolve(result);
    } else {
      reject(new Error("\xA1Error! N\xFAmero aleatorio demasiado alto: " + randomNumber));
    }
  });
}
function simulatePromiseRandomWith3seconds(result) {
  return new Promise((resolve, reject) => {
    setTimeout(() => {
      const randomNumber = Math.random();
      if (randomNumber < 0.5) {
        resolve(result);
      } else {
        reject(new Error("\xA1Error! N\xFAmero aleatorio demasiado alto: " + randomNumber));
      }
    }, 1e3);
  });
}

// src/utils/validation.util.ts
var validateRut = (rut) => {
  var regex = /^[0-9]+[-|‐]{1}[0-9kK]{1}$/.test(rut);
  if (!regex)
    return false;
  var valor = rut.replace("-", "");
  var cuerpo = valor.slice(0, -1);
  var dv = valor.slice(-1).toUpperCase();
  rut = cuerpo + "-" + dv;
  if (cuerpo.length < 7) {
    return false;
  }
  var suma = 0;
  var multiplo = 2;
  for (var i = 1; i <= cuerpo.length; i++) {
    const index = multiplo * parseInt(valor.charAt(cuerpo.length - i));
    suma = suma + index;
    if (multiplo < 7) {
      multiplo = multiplo + 1;
    } else {
      multiplo = 2;
    }
  }
  var dvEsperado = 11 - suma % 11;
  var dv_final = parseInt(dv);
  dv_final = dv === "K" ? 10 : dv_final;
  dv_final = dv === "0" ? 11 : dv_final;
  if (dvEsperado !== dv_final) {
    return false;
  }
  return true;
};
function isURL(cadena) {
  const patronURL = /^https?:\/\/(?:www\.)?[^\s/$.?#].[^\s]*$/;
  if (patronURL.test(cadena))
    return true;
  return false;
}
export {
  FormData,
  FormDataFile,
  copyFolder,
  createFolderIfNotExists,
  downloadImage,
  findFolder,
  formatCapitalizeFirstLetter,
  formatToCLP,
  getDate,
  getDay,
  getMonth,
  getYear,
  isURL,
  parsePath,
  randomAlphaNumeric,
  simulatePromise,
  simulatePromiseRandom,
  simulatePromiseRandomWith3seconds,
  updateVersion,
  validateRut,
  withoutCharacterSpecial
};
